@@ -8,8 +8,9 @@ from typing import Optional
 
 import click
 
-from bo4e_generator.parser import bo4e_init_file_content, bo4e_version_file_content, parse_bo4e_schemas
+from bo4e_generator.parser import OutputType, bo4e_init_file_content, bo4e_version_file_content, parse_bo4e_schemas
 from bo4e_generator.schema import get_namespace, get_version
+from bo4e_generator.sqlparser import format_code
 
 
 def resolve_paths(input_directory: Path, output_directory: Path) -> tuple[Path, Path]:
@@ -26,7 +27,7 @@ def resolve_paths(input_directory: Path, output_directory: Path) -> tuple[Path,
 def generate_bo4e_schemas(
     input_directory: Path,
     output_directory: Path,
-    pydantic_v1: bool = False,
+    output_type: OutputType,
     clear_output: bool = False,
     target_version: Optional[str] = None,
 ):
@@ -35,7 +36,7 @@ def generate_bo4e_schemas(
     """
     input_directory, output_directory = resolve_paths(input_directory, output_directory)
     namespace = get_namespace(input_directory)
-    file_contents = parse_bo4e_schemas(input_directory, namespace, pydantic_v1)
+    file_contents = parse_bo4e_schemas(input_directory, namespace, output_type)
     version = get_version(target_version, namespace)
     file_contents[Path("__version__.py")] = bo4e_version_file_content(version)
     file_contents[Path("__init__.py")] = bo4e_init_file_content(namespace, version)
@@ -45,9 +46,9 @@ def generate_bo4e_schemas(
     for relative_file_path, file_content in file_contents.items():
         file_path = output_directory / relative_file_path
         file_path.parent.mkdir(parents=True, exist_ok=True)
-        file_path.write_text(file_content, "utf-8")
+        file_content = format_code(file_content)
+        file_path.write_text(file_content, encoding="utf-8")
         print(f"Created {file_path}")
-
     print("Done.")
 
 
@@ -67,12 +68,13 @@ def generate_bo4e_schemas(
     required=True,
 )
 @click.option(
-    "--pydantic-v1/--pydantic-v2",
-    "-p1/-p2",
-    is_flag=True,
-    help="Generate pydantic v1 models instead of pydantic v2 models.",
+    "--output-type",
+    "-ot",
+    type=click.Choice(list(map(lambda x: x.name, OutputType)), case_sensitive=False),
+    # Taken from https://github.com/pallets/click/issues/605#issuecomment-889462570
+    help="Output type for the generated python files.",
     required=False,
-    default=False,
+    default=OutputType.PYDANTIC_V2,
 )
 @click.option(
     "--clear-output",
@@ -92,12 +94,12 @@ def generate_bo4e_schemas(
 )
 @click.version_option(package_name="BO4E-Python-Generator")
 def main(
-    input_dir: Path, output_dir: Path, pydantic_v1: bool, clear_output: bool, target_version: Optional[str] = None
+    input_dir: Path, output_dir: Path, clear_output: bool, output_type: OutputType, target_version: Optional[str] = None
 ):
     """
     CLI entry point for the bo4e-generator.
     """
-    generate_bo4e_schemas(input_dir, output_dir, pydantic_v1, clear_output, target_version)
+    generate_bo4e_schemas(input_dir, output_dir, output_type, clear_output, target_version)
 
 
 if __name__ == "__main__":
